@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006 - 2015 René Rebe, ExactCODE GmbH
+ * Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -88,13 +88,13 @@ int ImageCodec::Read (std::istream* stream, Image& image,
 	  // use primary entry to only try each codec once
 	  if (it->primary_entry && !it->via_codec_only) {
 	    int res = it->loader->readImage (stream, image, decompress, index);
-	    if (res > 0)
+	    if (res != 0)
 	    {
 	      image.setDecoderID (it->loader->getID ());
 	      //realignImage(image, image.stride() + 3);
 	      return res;
 	    }
-	    // TODO: remove once the codecs are clean
+	    // TODO: remove once all codecs reset the stream pos
 	    stream->clear ();
 	    stream->seekg (0);
 	  }
@@ -195,7 +195,7 @@ int ImageCodec::Read (std::string file, Image& image, const std::string& decompr
   }
   
   int res = Read (s, image, codec, decompress, index);
-  if (s != &std::cin)
+  if (s != &std::cin && res >= 0)
     delete s;
   return res;
 }
