@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006 - 2016 René Rebe
+ * Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 #include "raw.hh"
 
-int RAWCodec::readImage(std::istream* stream, Image& image, const std::string& decompres)
+int RAWCodec::readImage(std::istream* stream, Image& image, const std::string& decompress)
 {
   if (image.w <= 0 || image.bps == 0 || image.spp == 0) {
     std::cerr << "RAWCodec: image parameters not sufficently defined!" << std::endl;
@@ -71,9 +71,8 @@ bool RAWCodec::writeImage (std::ostream* stream, Image& image, int quality,
   if (!image.getRawData())
     return false;
 
-  return stream->write ((char*)image.getRawData(), image.stride()*image.h)
-    /* ==
-       (size_t) image.stride()*image.h*/;
+  stream->write((char*)image.getRawData(), image.stride()*image.h);
+  return stream->good();
 }
 
 RAWCodec raw_loader;
