@@ -1,6 +1,6 @@
 /*
  * Colorspace conversions.
- * Copyright (C) 2006 - 2016 René Rebe, ExactCODE GmbH, Germany.
+ * Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH, Germany.
  * Copyright (C) 2007 Susanne Klaus, ExactCODE GmbH, Germany.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -294,7 +294,7 @@ struct colorspace_cmyk_to_rgb_template
   void operator() (Image& image)
   {
     T it(image);
-    image.spp = 3; // update early, for out stride
+    image.spp = 3; // update early, for our stride
     image.rowstride = 0;
     T2 ot(image);
     
@@ -968,6 +968,7 @@ void colorspace_de_palette(Image& image, int table_entries,
   uint8_t* data = image.getRawData();
   uint32_t stride = image.stride();
   assert(orig_stridefill <= stride);
+  
   // TODO: allow 16bit output if the palette contains that much dynamic
   const uint8_t bitmask = (1 << orig_bps) - 1;
   for (int y = image.h - 1; y >= 0; --y) {
@@ -1002,7 +1003,7 @@ void colorspace_de_palette(Image& image, int table_entries,
       if (is_gray) {
 	*--dst = rmap[v] >> 8;
       } else {
-	if (amap) *--dst = amap[v >> 8];
+	if (amap) *--dst = amap[v] >> 8;
 	*--dst = bmap[v] >> 8;
 	*--dst = gmap[v] >> 8;
 	*--dst = rmap[v] >> 8;
